#!/bin/bash

## online.xml file as a first command-line parameter
if [[ -z $1 ]]; then
    onlinexml=""
else
    onlinexml=$1
fi

hname=$(hostname)
echo "hostname: $hname"

## NXSConfigServer name
if [ "$hname" == "haspp10e1" ]; then
    server="haspp10e1:10000/p10/nxsconfigserver/haspp10e1"
elif [ "$hname" == "haso228k" ]; then
    server="p06/nxsconfigserver/haso228"
else
    echo "Unknown host $hname"
    exit -1
fi

## create the configuration on the local file system
#stdopt="-d . -r $server"
#tgopt=""
#dsopt="-d . -r $server"
#cpopt="-d . -r $server"

## create the configuration in the NXSConfigServer DB
stdopt="-r $server -o -e haspp10e1:10000/p10/nxsconfigserver/haspp10e1"
tgopt="-b -r $server -o"
dsopt="-b -r $server $onlinexml -e haspp10e1:10000/p10/nxsconfigserver/haspp10e1"
cpopt="-r $server -o $onlinexml -e haspp10e1:10000/p10/nxsconfigserver/haspp10e1"


## online.xml datasources

nxscreate onlineds $dsopt


## default

nxscreate stdcomp -t default  -c default longname "P10 Coherence Applications Beamline" shortname P10  $stdopt

## beamtime_id

nxscreate stdcomp -t beamtimeid -c beamtime_id shortname P10  $stdopt

## source

nxscreate tangods  -v petra/globals/keyword -s source_energy -u haspp10opt -t 10000 -a Energy $tgopt
nxscreate tangods  -v petra/globals/keyword -s source_current -u haspp10opt -t 10000 -a BeamCurrent $tgopt
nxscreate stdcomp -t source -c source beamcurrent source_current sourceenergy source_energy $stdopt

## undulator

nxscreate tangods  -v p10/undulator/1 -s undulator_harmonic -u haspp10opt -t 10000 -a Harmonic $tgopt
nxscreate tangods  -v p10/undulator/1 -s undulator_taper -u haspp10opt -t 10000 -a Taper $tgopt
nxscreate stdcomp -t undulator -c undulator gap undulatorgap harmonic undulator_harmonic taper undulator_taper energy undulator $stdopt

## pslit1

nxscreate stdcomp -t slit -c pslit1 ygap ps1vgap yoffset ps1vcen $stdopt

## pslit2

nxscreate stdcomp -t slit -c pslit2 ygap ps2vgap yoffset ps2vcen left ps2hleft right ps2hright $stdopt

## gslit1

nxscreate stdcomp -t slit -c gslit1 ygap g1dy yoffset g1cy xgap g1dx xoffset g1cx top g1top bottom g1bottom left g1left right g1right $stdopt

## oslit1

nxscreate stdcomp -t slit -c oslit1 ygap oslt1dy yoffset oslt1cy xgap oslt1dx xoffset oslt1cx top oslt1_top bottom oslt1_bottom left oslt1_left right oslt1_right $stdopt

## uslit1

nxscreate stdcomp -t slit -c uslit1 ygap uslt1dy yoffset uslt1cy xgap uslt1dx xoffset uslt1cx top uslt1_top bottom uslt1_bottom left uslt1_left right uslt1_right $stdopt

## uslit2

nxscreate stdcomp -t slit -c uslit2 ygap uslt2dy yoffset uslt2cy xgap uslt2dx xoffset uslt2cx top uslt2_top bottom uslt2_bottom left uslt2_left right uslt2_right $stdopt

## rslit1

nxscreate stdcomp -t slit -c rslit1 ygap rslt1dy yoffset rslt1cy xgap rslt1dx xoffset rslt1cx top rslt1_top bottom rslt1_bottom left rslt1_left right rslt1_right $stdopt


## dcm_mono 

nxscreate stdcomp -t dcm -c dcm_mono crystal dcm_mono_crystal  dcmdevice haspp10opt:10000/p10/dcmener/opt.01 energyfmb energyfmb_common exitoffset exitoffset energy p10energy braggangle dcm_bragg jack1 monoz_r jack2 monoz_lu jack3 monoz_ld table monoz lat monoy yaw monorz pitch2 c2_pitch roll2 c2_roll perp2 c2_perp par2 c2_para $stdopt
#nxscreate stdcomp -t dcm -c dcm crystal dcm_mono_crystal  dcmdevice haspp10opt:10000/p10/dcmenergy/opt.01 energyfmb  mnchrmtr exitoffset dcm_exitoffset lat2 dcm_2nd_lateral  par2 dcm_2nd_longitudinal  pitch2 dcm_2nd_pitch roll2 dcm_2nd_roll roll1 dcm_1st_roll yaw dcm_1st_yaw yaw2 dcm_2nd_yaw energy mnchrmtr pitch1 dcm_1st_pitch bend1 dcm_1st_bend bend2 dcm_2nd_bend topdependson2 lat phi1dependson theta chi2dependson phi  $stdopt

## optional
#nxscreate tangods  -v p10/dcmener/opt.01 -s dcm_exitoffset -u haspp10opt -t 10000 -a ExitOffset $tgopt
nxscreate tangods  -v p10/dcmener/opt.01 -s dcm_mono_crystal -u haspp10opt -t 10000 -a Crystal  $tgopt
# #nxscreate tangods  -v p07/dcmmotor/01 -s dcm_mono_unitcalibration -u hzgpp07oh1 -t 10000 -a UnitCalibration $tgopt

## energyfmb_common

nxscreate stdcomp -t common2 -c energyfmb dds fmbenergy ods mnchrmtr $stdopt

## dcm_energy (from crystal)

nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/dcm_mono:NXmonochromator/collection:NXcollection/dcmenergy' -s dcmenergy dcm_energy -g INIT -t NX_FLOAT64 -k -u eV -m $tgopt


## ucc_mono

nxscreate stdcomp -t chcut -c ucc_mono crystal ucc_mono_crystal  chcutdevice haspp10opt:10000/p10/dcmener/opt.01  braggangle uccth table monoz lat monoy reflection "1 1 1"  $stdopt


## ucc_energy

nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/ucc_mono:NXmonochromator/collection:NXcollection/uccenergy' -s uccenergy ucc_energy -g INIT -t NX_FLOAT64 -k -u eV -m $tgopt

## optional
nxscreate tangods  -v p10/dcmener/opt.01 -s ucc_mono_crystal -u haspp10opt -t 10000 -a Crystal  $tgopt

## rcc_mono

nxscreate stdcomp -t chcut -c rcc_mono crystal rcc_mono_crystal  chcutdevice haspp10opt:10000/p10/dcmener/opt.01  braggangle rccpitch  table rcctz lat rccty theta rccry  reflection "3 3 3" $stdopt

## optional
nxscreate tangods  -v p10/dcmener/opt.01 -s rcc_mono_crystal -u haspp10opt -t 10000 -a Crystal  $tgopt

## rcc_energy

nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/rcc_mono:NXmonochromator/collection:NXcollection/rccenergy' -s rccenergy rcc_energy -g INIT -t NX_FLOAT64 -k -u eV -m $tgopt


## mirrors

nxscreate stdcomp -p nxsextrasp10 -t mirrors -c mirrors pitch1 mir1rz x1 mir1y y1 mirz pitch2 mir2rz x2 mir2y y2 mirz offset mircy gap mirdy x lm2y y lm2z $stdopt

## girder

nxscreate stdcomp -p nxsextrasp10 -t girder -c girder x1 girdery1 y1 girderz1  x2 girdery2 y2 girderz2 x girdery y girderz $stdopt

## bpm

#nxscreate stdcomp -t qbpm -c bpm foil bpm_foil foilpos bpm_mon foilposdict '{"Ti": 43, "Ni": 23, "Out": 4}' x  bpmy y bpmz $stdopt
nxscreate stdcomp -t qbpm -c bpm  foilpos bpm_mon x  bpmy y bpmz $stdopt

## bm

nxscreate stdcomp -t qbpm -c bm  x mon1y $stdopt

## cryo

nxscreate stdcomp  -p nxsextrasp10 -t cryostage -c cryo x cryoy y cryoz z cryox  $stdopt


## usample_table (usaxs)

nxscreate stdcomp -p nxsextrasp10 -t sampletable -c usample_table postfix _ut pitchdependson x y1 utz1 y2 utz2 y3 utz3 x1 uty1 x2 uty2 yaw utrz pitch utry x uty y utz $stdopt

## usample_stage (usaxs)

nxscreate stdcomp -p nxsextrasp10 -t samplestage -c usample_stage postfix _usam pitchdependson x yaw usamrz pitch usamry x usamy y usamz z usamx $stdopt

## tomo_stage 

nxscreate stdcomp -p nxsextrasp10 -t samplestage -c tomo_stage postfix _tomo roll tomorx pitch tomory x tomoy z tomox $stdopt


## afm_stage (usaxs)

nxscreate stdcomp -p nxsextrasp10 -t samplestage -c afm_stage postfix _afm x afmy y afmz z afmx $stdopt

## diffractometer (usaxs)

nxscreate stdcomp -p nxsextrasp10 -t diffractometer -c diffractometer sname sample  gamma gam delta del chi chi phi phi omega om mu mu height diffz height1 diffz1 height2 diffz2 x diffy  $stdopt

## rsample_stage (usaxs)

nxscreate stdcomp -p nxsextrasp10 -t samplestage -c rsample_stage postfix _rsam  x rsy  z rsx $stdopt


## rsample_table (rheometer)

nxscreate stdcomp -p nxsextrasp10 -t sampletable -c rsample_table postfix _rt y1 rtz1 y2 rtz2 y3 rtz3 x1 rty1 x2 rty2 yaw rtrz pitch rtry roll rtrx x rty y rtz $stdopt

## rdet_stage 

nxscreate stdcomp -p nxsextrasp10 -t detstage -c rdet_stage detname rdetector dependson x x rdy z rdx y rdz $stdopt

## rdiode_stage 

nxscreate stdcomp -p nxsextrasp10 -t detstage -c rdiode_stage detname rdio dependson x x rdiodey $stdopt

## rdio

nxscreate stdcomp -p nxsextrasp10 -t pointdet -c rdio detname rdio data rdio $stdopt

## udio

nxscreate stdcomp -p nxsextrasp10 -t pointdet -c udio detname udio data udio $stdopt

## diffdio

nxscreate stdcomp -p nxsextrasp10 -t pointdet -c diffdio detname diffdio data diffdio $stdopt

## e1diode2

nxscreate stdcomp -p nxsextrasp10 -t pointdet -c e1diode2 detname e1diode2 data e1diode2 $stdopt

## e1diode3

nxscreate stdcomp -p nxsextrasp10 -t pointdet -c e1diode3 detname e1diode3 data e1diode3 $stdopt

## mhz1

nxscreate stdcomp -p nxsextrasp10 -t pointdet -c mhz1 detname mhz1 data mhz1 $stdopt

## mhz2

nxscreate stdcomp -p nxsextrasp10 -t pointdet -c mhz2 detname mhz2 data mhz2 $stdopt

## amptek_roi

nxscreate stdcomp -p nxsextrasp10 -t pointdet -c amptek_roi detname amptek data amptek_roi $stdopt

## cbs1

nxscreate stdcomp -p nxsextrasp10 -t pointdet -c cbs1 detname cbs1 data cbs1 $stdopt

## cbs1_ll

nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/cbs1:NXdetector/collection:NXcollection/'  -g STEP -t NX_FLOAT64 -k cbs1_ll $tgopt

## cbs1_ul

nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/cbs1:NXdetector/collection:NXcollection/'  -g STEP -t NX_FLOAT64 -k cbs1_ul $tgopt

## rcrystal

nxscreate stdcomp -p nxsextrasp10 -t detstage -c rcrystal detname rcc_mono grouptype NXmonochromator dependson pitch pitch rcth yaw rcrz x rcy z rcx y rcz $stdopt
#nxscreate stdcomp -p nxsextrasp10 -t detstage -c rcrystal detname rcrystal grouptype NXcrystal dependson pitch pitch rcth yaw rcrz x rcy z rcx y rcz $stdopt


## optics_table

nxscreate stdcomp -p nxsextrasp10 -t opticstable -c optics_table postfix _ot1 pitchdependson x y1 ot1z1 y2 ot1z2 y3 ot1z3 x1 ot1y1 x2 ot1y2 yaw ot1rz pitch ot1ry x ot1y y ot1z $stdopt

## rbeamstop

nxscreate stdcomp -t beamstop -c rbeamstop x rbsy z rbsx  $stdopt

## rpinhole

nxscreate stdcomp -t pinhole -c rpinhole x rpx z rpy  $stdopt

## absorber1

nxscreate stdcomp  -t absorber -c absorber1 y abs1z  transformations  transformations $stdopt

## absorber2

nxscreate stdcomp  -t absorber -c absorber2 y abs2z transformations  transformations  $stdopt

## shutterstage

nxscreate stdcomp  -p nxsextrasp10 -t shutterstage -c shutterstage y fsz  $stdopt

## crl_hexapod

nxscreate tangods -v p10/hexapodconfig/hexa1.01 -s crl_hexapod_hexat -u haspp10e1 -t 10000 -a PositionPivotT $tgopt
nxscreate tangods -v p10/hexapodconfig/hexa1.01 -s crl_hexapod_hexas -u haspp10e1 -t 10000 -a PositionPivotS $tgopt
nxscreate tangods -v p10/hexapodconfig/hexa1.01 -s crl_hexapod_hexar -u haspp10e1 -t 10000 -a PositionPivotR $tgopt

nxscreate stdcomp -p nxsextrasp10 -t lenshexapod -c crl_hexapod x hexay y hexaz z hexax pivotx crl_hexapod_hexas  pivoty crl_hexapod_hexar pivotz crl_hexapod_hexat pitch hexary yaw hexarz roll hexarx $stdopt

## e1_vfcXY

nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/detector:NXdetector/collection:NXcollection/' -v e1_vfc -f4 -l5 -g STEP -t NX_FLOAT64 -k e1_vfc08 $tgopt

## e1_cXY

nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/detector:NXdetector/collection:NXcollection/' -v e1_c -f6 -l31 -g STEP -t NX_FLOAT64 -k e1_c04 $tgopt

## e1_mca

nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/e1_mca01:NXdetector/data'  e1_mca01  -g STEP -t NX_FLOAT64 -i  -c SPECTRUM $tgopt
nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/e1_mca02:NXdetector/data'  e1_mca02  -g STEP -t NX_FLOAT64 -i  -c SPECTRUM $tgopt
nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/e1_mca03:NXdetector/data'  e1_mca03  -g STEP -t NX_FLOAT64 -i  -c SPECTRUM $tgopt
nxscreate comp  -n  '/entry$var.serialno:NXentry/instrument/e1_mca04:NXdetector/data'  e1_mca04  -g STEP -t NX_FLOAT64 -i  -c SPECTRUM $tgopt


## ldev

nxscreate onlinecp -c ldev $cpopt

## l01

nxscreate onlinecp -c l01 $cpopt

## l02

nxscreate onlinecp -c l02 $cpopt

## lcx

nxscreate onlinecp -c lcx $cpopt

## e4m

nxscreate onlinecp -c e4m $cpopt

## p100

nxscreate onlinecp -c p100 $cpopt

## p300

nxscreate onlinecp -c p300 $cpopt

## p1m

nxscreate onlinecp -c p1m $cpopt

## pcoedge

nxscreate onlinecp -c pcoedge $cpopt

## mythen

nxscreate onlinecp -c mythen $cpopt

# # # ## set DefaultPreselectedComponents of NXSRecSelector/haspp10e1

# # # ##  nxsetup -c -n DefaultPreselectedComponents -w "[\"source\",\"undulator\",\"beamtime_id\",\"pslit1\",\"pslit2\",\"gslit1\",\"oslit1\",\"uslit1\",\"uslit2\",\"rslit1\",\"dcm_mono\",\"dcm_energy\",\"ucc_mono\",\"ucc_energy\",\"rcc_mono\",\"rcc_energy\",\"mirrors\",\"girder\",\"bpm\",\"bm\",\"cryo\",\"usample_table\",\"usample_stage\",\"tomo_stage\",\"afm_stage\",\"diffractometer\",\"rsample_stage\",\"rsample_table\",\"rdet_stage\",\"rdiode_stage\",\"rcrystal\",\"optics_table\",\"rbeamstop\",\"rpinhole\",\"absorber1\",\"absorber2\",\"shutterstage\",\"crl_hexapod\"]" NXSRecSelector/haspp10e1
